#!/bin/bash
# prev maintainer  : Pedro Pinto (pnboy~AT~pinguix.com)
# maintainer       : P.L. Smith (BandiPat magicpage91@earthlink.net)
# source location  : http://intermap.dl.sourceforge.net/sourceforge/krusader/krusader-2.0.0.tar.gz
# additional files : 
# additional info  :  Built for Zenwalk 6.x and KDE4

#
# what package is going to be built
#
softname='krusader'
softversion='2.0.0'

#
# The ZenWalk package version: indicated for/on what ZenWalk version
# the package has been created
#
# example: packageversion='1Z20' means: 
# 1  -> build 1 = first build, special: 0 = experimental/unsupported build
# Z  -> ZenWalk
# 20 -> ZenWalk version 2.0; 26 -> zenwalk 2.6 
#
packageversion='62.2'

#
# where could you get the source
#
srcurl="http://intermap.dl.sourceforge.net/sourceforge/krusader/krusader-2.0.0.tar.gz"

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 make-jobs at once
#
#numjobs='-j6'
#
# I only have a 'light' computer: 2 make-jobs at once
#
numjobs='-j2'

#
#---------------------------------------------------------------------
# Note: for a rebuild you should normally not have to change anything
# below this comment
#---------------------------------------------------------------------
#

#
# a lonesome 'hook': the other end is at the bottom of the buildfile
# the combination gives me a full log of the build-process in the
# file: "$softname-$softversion-info.txt"
#
(

#
# we're going to do some cwd-hopping: this requires that we keep track
# of the starting-point
#
buildir=$(pwd)

#
# We'll use the SlackWare/ZenWalk database of installed packages: 
# The directory: /var/log/packages keeps a set of all installed 
# ZenWalk packages: one file per installed package
#

echo "-- dependencies check -----"

depsok=passed

cd /var/log/packages
 
#
# 
#
for file in \
	kdelibs \
; do
 
   #
   # Check the dependency
   #
   if [ -f $file* ] ; then 
      echo "package: $file is installed: `ls -d $file*`: good ...";
   else
      echo "package: $file not found: please install a $file package first";
      depsok=fail
   fi

done

cd $buildir
 
echo "Dependencies check result: $depsok"
#
# check if all dependencies are there
#
if [[ $depsok == passed ]]; then
   unset $depsok;
else
   exit 1;
fi

#
# check if the source files archive is present: we can do little without
# it
#
cat <<"EOF"
-- source archive check -----
EOF

if [ -r "$softname-$softversion.tar.gz" ]; then 
  echo "Usable source archive: $softname-$softversion.tar.gz found: good ...";
else 
  echo "No source archive: $softname-$softversion.tar.gz found"
  echo "It is not possible to build the package without a source archive"
  echo "file; Please download the source archive from:"
  echo
  echo "$srcurl"
  echo
  exit 1;
fi

#
# start the real work
#
echo "-- start of the package building -----"

#
# the package 'destination'
#
prefix=/usr

#
# The architecture that the package is built for:
#
# arch='i486' -> the compiler uses only 80486 instructions
# tune='i686'  -> the optimising is done for a PII and above CPU
#
arch='i486'
tune='i686'

#
# parameters needed for the build process
#
package="$softname-$softversion-$arch-$packageversion"

#
# do package-specific settings 
#
# This avoids compiling a version number into KDE's .la files:
# export QTDIR=/usr/lib/qt
# export PATH=$QTDIR/bin:$PATH
export KDEDIR=/usr/lib/kde4
export PATH=$KDEDIR/bin:$PATH

#
# prepare the build result directory
#
dest="$buildir/$package"
#
rm -rf $dest
#
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix
mkdir -p $dest/$prefix/bin
#
# prepare the directory for the build-file and assorted other 
# user-build related things
#
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

#
# put a slack-desc in place
#
#        |-----handy-ruler------------------------------------------------------|
cat <<EOF > $dest/install/slack-desc

$softname:        Krusader 2.0.0 - An advanced twin panel file manager
$softname: 
$softname: Krusader 2.0.0 is a commander style file manager for KDE4/QT4
$softname: and other desktops in the *nix world, similar to Midnight or
$softname: Total Commander. It provides all the file management features you
$softname: could possibly want.
$softname: 
$softname: This piece of software is developed by the Krusader Krew, published
$softname: under the GNU General Public Licence.
$softname:
$softname: 
EOF

echo "-- Unpacking the source archive -----"

#
# loop over expanded package source files
#
cd $buildir
file=$softname-$softversion.tar.gz
srcdir="$(basename $file .tar.gz)" 
rm -rf $srcdir
tar xvfz $file
cd $srcdir  

#
# set target permissions
#
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

#
# configure package for compilation
#
echo "-- configure -----"

export CFLAGS="-O2 -march=$arch -mtune=$tune"  
export CXXFLAGS="-O2 -march=$arch -mtune=$tune" 

/usr/bin/cmake -DCMAKE_INSTALL_PREFIX=$prefix ../ $buildir/$srcdir || return 1


#
# make package
#
echo "-- make -----"
make $numjobs || return 1

#
# install package to the target directory
#
echo "-- make install -----"
make install DESTDIR=$dest || return 1

#
# add 'default' files from the package source
#
echo "-- adding default files -----"

mkdir -p $dest/usr/doc/$srcdir
cp -a \
  AUTHORS COPYING ChangeLog FAQ INSTALL SVNNEWS README TODO \
  $dest/usr/doc/$srcdir 

# 
# as per package rules: add the build-file itself
#
echo "-- adding package-rules files -----"

cp "$buildir/build-$softname.sh" \
   "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"
#
# generate an executable script that can be used to get the source
#
cat <<EOF > "$destsrc/getsrc.sh"
# 
# get the source(s) script
#
wget -c $srcurl
EOF

#
# it works easier if this file is actually executable :-)
#
chmod a+x "$destsrc/getsrc.sh"

#
# post-build processing: 
# - strip executables 
# - compress man-pages
#
echo "-- pre-package processing files -----"
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  for mandir in $(find . -name man -type d) ; do
    if [ -d $mandir ]; then
      ( cd $mandir
        find . -type f -name "*.?" -exec gzip -9 {} \;
      )
    fi
  done
)

#
# real packaging work: 
#
chown -R root.root $dest/$prefix

echo "--- packaging -----"

cd $dest
makepkg -p -l y -c n $dest.tlz
(
 cd $buildir
 echo "-- md5 generation -----"
 md5sum $package.tlz >$package.md5
 echo "-- deps generation -----"
 depfinder -f  $package.tlz >$package.dep
 echo "-- src file generation -----"
 echo $srcurl >$package.src
 echo "---generating build text---"
#
# produce the file src
#
echo http://zenwalk.pinguix.com/user-accounts/BandiPat/source/build-files/build-krusader.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/BandiPat/source/krusader-2.0.0.tar.gz >> $package.src
echo $srcurl >> $package.src
)

#
# the other end of the lonesome hook: 
#
) 2>&1 | tee "$softname-$softversion-build.txt"

